<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt" sourcelanguage="en">
  <context>
    <name>CmdRobotAddToolShape</name>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="210"/>
      <source>Robot</source>
      <translation>Robotas</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="211"/>
      <source>Add tool</source>
      <translation>Pridėti įrankį</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="212"/>
      <source>Add a tool shape to the robot</source>
      <translation>Pridėti robotui įrankio formą</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="154"/>
      <source>Robot</source>
      <translation>Robotas</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="155"/>
      <source>Place robot...</source>
      <translation>Padėti robotą...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="156"/>
      <source>Place a robot (experimental!)</source>
      <translation>Padėti robotą (bandomasis!)</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotCreateTrajectory</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="55"/>
      <source>Robot</source>
      <translation>Robotas</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="56"/>
      <source>Create trajectory</source>
      <translation>Sukurti judėjimo kelią</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="57"/>
      <source>Create a new empty trajectory</source>
      <translation>Sukurti naują tuščią judėjimo kelią</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotEdge2Trac</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="314"/>
      <source>Robot</source>
      <translation>Robotas</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="315"/>
      <source>Edge to Trajectory...</source>
      <translation>Judėjimo kelio kraštinė...</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="316"/>
      <source>Generate a Trajectory from a set of edges</source>
      <translation>Kurti Judėjimo kelią iš kraštinių</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotExportKukaCompact</name>
    <message>
      <location filename="../../CommandExport.cpp" line="46"/>
      <source>Robot</source>
      <translation>Robotas</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="47"/>
      <source>Kuka compact subroutine...</source>
      <translation>Kuka compact paprogramė...</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="48"/>
      <source>Export the trajectory as a compact KRL subroutine.</source>
      <translation>Eksportuoti judėjimo kelią kaip suglaudintą KRL paprogramę.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotExportKukaFull</name>
    <message>
      <location filename="../../CommandExport.cpp" line="108"/>
      <source>Robot</source>
      <translation>Robotas</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="109"/>
      <source>Kuka full subroutine...</source>
      <translation>Kuka pilnoji paprogramė...</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="110"/>
      <source>Export the trajectory as a full KRL subroutine.</source>
      <translation>Eksportuoti judėjimo kelią kaip pilnąją KRL paprogramę.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertKukaIR125</name>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="169"/>
      <source>Robot</source>
      <translation>Robotas</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="170"/>
      <source>Kuka IR125</source>
      <translation>Kuka IR125</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="171"/>
      <source>Insert a Kuka IR125 into the document.</source>
      <translation>Į dokumentą įterpti Kuka IR125.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertKukaIR16</name>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="88"/>
      <source>Robot</source>
      <translation>Robotas</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="89"/>
      <source>Kuka IR16</source>
      <translation>Kuka IR16</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="90"/>
      <source>Insert a Kuka IR16 into the document.</source>
      <translation>Įterpti Kuka IR16 į dokumentą.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertKukaIR210</name>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="129"/>
      <source>Robot</source>
      <translation>Robotas</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="130"/>
      <source>Kuka IR210</source>
      <translation>Kuka IR210</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="131"/>
      <source>Insert a Kuka IR210 into the document.</source>
      <translation>Į dokumentą įterpti Kuka IR210.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertKukaIR500</name>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="46"/>
      <source>Robot</source>
      <translation>Robotas</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="47"/>
      <source>Kuka IR500</source>
      <translation>Kuka IR500</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="48"/>
      <source>Insert a Kuka IR500 into the document.</source>
      <translation>Į dokumentą įterpti Kuka IR500.</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertWaypoint</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="88"/>
      <source>Robot</source>
      <translation>Robotas</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="89"/>
      <source>Insert in trajectory</source>
      <translation>Įterpti į judėjimo kelią</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="90"/>
      <source>Insert robot Tool location into trajectory</source>
      <translation>Į judėjimo kelią Įterpti roboto Įrankio padėtį</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotInsertWaypointPreselect</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="145"/>
      <source>Robot</source>
      <translation>Robotas</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="146"/>
      <source>Insert in trajectory</source>
      <translation>Įterpti į judėjimo kelią</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="147"/>
      <source>Insert preselection position into trajectory (W)</source>
      <translation>Įterpti pirminę padėtį į judėjimo kelią (W)</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotRestoreHomePos</name>
    <message>
      <location filename="../../Command.cpp" line="100"/>
      <source>Robot</source>
      <translation>Robotas</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="101"/>
      <location filename="../../Command.cpp" line="102"/>
      <source>Move to home</source>
      <translation>Perkelti į pradžią</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotSetDefaultOrientation</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="209"/>
      <source>Robot</source>
      <translation>Robotas</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="210"/>
      <source>Set default orientation</source>
      <translation>Nustatyti numatytąją erdvinę padėtį</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="211"/>
      <source>Set the default orientation for subsequent commands for waypoint creation</source>
      <translation>Nustatyti numatytąją erdvinę padėtį sekančioms komandoms tarpinio taško sukūrimui</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotSetDefaultValues</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="248"/>
      <source>Robot</source>
      <translation>Robotas</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="249"/>
      <source>Set default values</source>
      <translation>Nustatyti numatytąsias reikšmes</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="250"/>
      <source>Set the default values for speed, acceleration and continuity for subsequent commands of waypoint creation</source>
      <translation>Nustatyti numatytąsias greičio, pagreičio ir glotnumo reikšmes sekantiems veiksmams tarpinių taškų sukūrimui</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotSetHomePos</name>
    <message>
      <location filename="../../Command.cpp" line="51"/>
      <source>Robot</source>
      <translation>Robotas</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="52"/>
      <location filename="../../Command.cpp" line="53"/>
      <source>Set the home position</source>
      <translation>Nustatyti pagrindinę padėtį</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotSimulate</name>
    <message>
      <location filename="../../Command.cpp" line="195"/>
      <source>Robot</source>
      <translation>Robotas</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="196"/>
      <source>Simulate a trajectory</source>
      <translation>Modeliuoti judėjimo kelią</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="197"/>
      <source>Run a simulation on a trajectory</source>
      <translation>Vykdyti judėjimo kelio modeliavimą</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotTrajectoryCompound</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="425"/>
      <source>Robot</source>
      <translation>Robotas</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="426"/>
      <source>Trajectory compound...</source>
      <translation>Judėjimo kelio junginys...</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="427"/>
      <source>Group and connect some trajectories to one</source>
      <translation>Grupuoti ir apjungti kelis judėjimo kelius į vieną</translation>
    </message>
  </context>
  <context>
    <name>CmdRobotTrajectoryDressUp</name>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="378"/>
      <source>Robot</source>
      <translation>Robotas</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="379"/>
      <source>Dress-up trajectory...</source>
      <translation>Judėjimo kelio keitimas...</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="380"/>
      <source>Create a dress-up object which overrides some aspects of a trajectory</source>
      <translation>Sukurti keičiantįjį objektą, kuris pakeičia judėjimo kelio savybes</translation>
    </message>
  </context>
  <context>
    <name>Gui::TaskView::TaskWatcherCommands</name>
    <message>
      <location filename="../../Workbench.cpp" line="51"/>
      <source>Trajectory tools</source>
      <translation>Judėjimo kelio įrankiai</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="52"/>
      <source>Robot tools</source>
      <translation>Roboto įrankiai</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="53"/>
      <source>Insert Robot</source>
      <translation>Įdėti robotą</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Command.cpp" line="71"/>
      <location filename="../../Command.cpp" line="120"/>
      <location filename="../../Command.cpp" line="220"/>
      <location filename="../../Command.cpp" line="249"/>
      <location filename="../../CommandExport.cpp" line="61"/>
      <location filename="../../CommandExport.cpp" line="123"/>
      <location filename="../../CommandInsertRobot.cpp" line="229"/>
      <location filename="../../CommandTrajectory.cpp" line="104"/>
      <location filename="../../CommandTrajectory.cpp" line="160"/>
      <location filename="../../CommandTrajectory.cpp" line="177"/>
      <location filename="../../CommandTrajectory.cpp" line="406"/>
      <source>Wrong selection</source>
      <translation>Netinkama pasirinktis</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="72"/>
      <source>Select one Robot to set home position</source>
      <translation>Pasirinkite vieną robotą pradinei padėčiai nustatyti</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="121"/>
      <source>Select one Robot</source>
      <translation>Pasirinkite vieną Robotą</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="221"/>
      <location filename="../../Command.cpp" line="250"/>
      <location filename="../../CommandExport.cpp" line="62"/>
      <location filename="../../CommandExport.cpp" line="124"/>
      <location filename="../../CommandTrajectory.cpp" line="105"/>
      <source>Select one Robot and one Trajectory object.</source>
      <translation>Pasirinkite vieną robotą ir vieną judėjimo kelio objektą.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="226"/>
      <source>Trajectory not valid</source>
      <translation>Klaidingas judėjimo kelias</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="227"/>
      <source>You need at least two waypoints in a trajectory to simulate.</source>
      <translation>Trajektorijos modeliavimui jums reikia bent dviejų tarpinių taškų.</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="84"/>
      <location filename="../../CommandExport.cpp" line="146"/>
      <source>KRL file</source>
      <translation>KRL failas</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="85"/>
      <location filename="../../CommandExport.cpp" line="147"/>
      <source>All Files</source>
      <translation>Visi failai</translation>
    </message>
    <message>
      <location filename="../../CommandExport.cpp" line="86"/>
      <location filename="../../CommandExport.cpp" line="148"/>
      <source>Export program</source>
      <translation>Eksportuoti programą</translation>
    </message>
    <message>
      <location filename="../../CommandInsertRobot.cpp" line="230"/>
      <source>Select one robot and one shape or VRML object.</source>
      <translation>Pasirinkite vieną robotą ir vieną geometrinę figūrą arba VRML objektą.</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="161"/>
      <location filename="../../CommandTrajectory.cpp" line="178"/>
      <source>Select one Trajectory object.</source>
      <translation>Pasirinkite vieną judėjimo kelio objektą.</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="184"/>
      <source>No preselection</source>
      <translation>Nėra pirminio pažymėjimo</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="185"/>
      <source>You have to hover above a geometry (Preselection) with the mouse to use this command. See documentation for details.</source>
      <translation>Užveskite pelės žymeklį virš (pirminės) geometrijos, kad galėtumėte pasinaudoti šia komanda. Ieškokite smulkesnės informacijos žinyne.</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="262"/>
      <source>Set default speed</source>
      <translation>Nustatyti numatytąjį greitį</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="263"/>
      <source>speed: (e.g. 1 m/s or 3 cm/s)</source>
      <translation>greitis: (pvz., 1 m/s arba 3 cm/s)</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="272"/>
      <source>Set default continuity</source>
      <translation>Nustatyti numatytąjį glotnumą</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="273"/>
      <source>continuous ?</source>
      <translation>glotnus?</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="279"/>
      <source>Set default acceleration</source>
      <translation>Nustatyti numatytąjį pagreitį</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="280"/>
      <source>acceleration: (e.g. 1 m/s^2 or 3 cm/s^2)</source>
      <translation>pagreitis: (pvz. 1 m/s^2 arba 3 cm/s^2)</translation>
    </message>
    <message>
      <location filename="../../CommandTrajectory.cpp" line="407"/>
      <source>Select the Trajectory which you want to dress up.</source>
      <translation>Pasirinkite judėjimo kelią, kurį jūs norite pakeisti.</translation>
    </message>
    <message>
      <location filename="../../ViewProviderTrajectory.cpp" line="149"/>
      <source>Modify</source>
      <translation>Keisti</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="79"/>
      <source>No robot files installed</source>
      <translation>Nėra įdiegta robotų failų</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="80"/>
      <source>Please visit %1 and copy the files to %2</source>
      <translation>Prašome apsilankyti %1 ir nukopijuoti failus į %2</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::DlgTrajectorySimulate</name>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="20"/>
      <source>Simulation</source>
      <translation>Modeliavimas</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="58"/>
      <source>|&lt;</source>
      <translation>|&lt;</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="89"/>
      <source>&lt;</source>
      <translation>&lt;</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="151"/>
      <source>|&gt;</source>
      <translation>|&gt;</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="182"/>
      <source>&gt;</source>
      <translation>&gt;</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="213"/>
      <source>&gt;|</source>
      <translation>&gt;|</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="272"/>
      <source>Type</source>
      <translation>Rūšis</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="277"/>
      <source>Name</source>
      <translation>Pavadinimas</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="282"/>
      <source>C</source>
      <translation>C</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="287"/>
      <source>V</source>
      <translation>V</translation>
    </message>
    <message>
      <location filename="../../TrajectorySimulate.ui" line="292"/>
      <source>A</source>
      <translation>A</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskEdge2TracParameter</name>
    <message>
      <location filename="../../TaskEdge2TracParameter.cpp" line="42"/>
      <source>TaskEdge2TracParameter</source>
      <translation type="unfinished">TaskEdge2TracParameter</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskRobot6Axis</name>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="14"/>
      <source>Form</source>
      <translation>Pavidalas</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="22"/>
      <source>A1</source>
      <translation>A1</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="69"/>
      <source>A2</source>
      <translation>A2</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="116"/>
      <source>A3</source>
      <translation>A3</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="163"/>
      <source>A4</source>
      <translation>A4</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="210"/>
      <source>A5</source>
      <translation>A5</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="257"/>
      <source>A6</source>
      <translation>A6</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="313"/>
      <source>TCP: (200.23,300.23,400.23,234,343,343)</source>
      <translation>TCP: (200.23,300.23,400.23,234,343,343)</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.ui" line="329"/>
      <source>Tool: (0,0,400,0,0,0)</source>
      <translation>Įrankis: (0,0,400,0,0,0)</translation>
    </message>
    <message>
      <location filename="../../TaskRobot6Axis.cpp" line="41"/>
      <source>TaskRobot6Axis</source>
      <translation type="unfinished">TaskRobot6Axis</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskRobotControl</name>
    <message>
      <location filename="../../TaskRobotControl.cpp" line="35"/>
      <source>TaskRobotControl</source>
      <translation type="unfinished">TaskRobotControl</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskRobotMessages</name>
    <message>
      <location filename="../../TaskRobotMessages.cpp" line="35"/>
      <source>TaskRobotMessages</source>
      <translation type="unfinished">TaskRobotMessages</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskTrajectory</name>
    <message>
      <location filename="../../TaskTrajectory.ui" line="20"/>
      <source>Form</source>
      <translation>Pavidalas</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="58"/>
      <source>|&lt;</source>
      <translation>|&lt;</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="89"/>
      <source>&lt;</source>
      <translation>&lt;</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="151"/>
      <source>|&gt;</source>
      <translation>|&gt;</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="182"/>
      <source>&gt;</source>
      <translation>&gt;</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="213"/>
      <source>&gt;|</source>
      <translation>&gt;|</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="254"/>
      <source>10 ms</source>
      <translation>10 ms</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="259"/>
      <source>50 ms</source>
      <translation>50 ms</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="264"/>
      <source>100 ms</source>
      <translation>100 ms</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="269"/>
      <source>500 ms</source>
      <translation>500 ms</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="274"/>
      <source>1 s</source>
      <translation>1 s</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="291"/>
      <source>Pos: (200.23, 300.23, 400.23, 234, 343 ,343)</source>
      <translation>Padėtis: (200.23, 300.23, 400.23, 234, 343, 343)</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="317"/>
      <source>Type</source>
      <translation>Rūšis</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="322"/>
      <source>Name</source>
      <translation>Pavadinimas</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="327"/>
      <source>C</source>
      <translation>C</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="332"/>
      <source>V</source>
      <translation>V</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.ui" line="337"/>
      <source>A</source>
      <translation>A</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectory.cpp" line="37"/>
      <source>Trajectory</source>
      <translation type="unfinished">Trajectory</translation>
    </message>
  </context>
  <context>
    <name>RobotGui::TaskTrajectoryDressUpParameter</name>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.cpp" line="41"/>
      <source>Dress Up Parameter</source>
      <translation type="unfinished">Dress Up Parameter</translation>
    </message>
  </context>
  <context>
    <name>TaskEdge2TracParameter</name>
    <message>
      <location filename="../../TaskEdge2TracParameter.ui" line="14"/>
      <source>Form</source>
      <translation>Pavidalas</translation>
    </message>
    <message>
      <location filename="../../TaskEdge2TracParameter.ui" line="29"/>
      <source>Hide / Show</source>
      <translation>Slėpti/Rodyti</translation>
    </message>
    <message>
      <location filename="../../TaskEdge2TracParameter.ui" line="47"/>
      <source>Edges: 0</source>
      <translation>Kraštinių: 0</translation>
    </message>
    <message>
      <location filename="../../TaskEdge2TracParameter.ui" line="61"/>
      <source>Cluster: 0</source>
      <translation>Sankaupos: 0</translation>
    </message>
    <message>
      <location filename="../../TaskEdge2TracParameter.ui" line="72"/>
      <source>Sizing Value:</source>
      <translation>Kalibravimo Reikšmė:</translation>
    </message>
    <message>
      <location filename="../../TaskEdge2TracParameter.ui" line="103"/>
      <source>Use orientation of edge</source>
      <translation>Naudoti kraštinės kampinę padėtį</translation>
    </message>
  </context>
  <context>
    <name>TaskRobotControl</name>
    <message>
      <location filename="../../TaskRobotControl.ui" line="14"/>
      <source>Form</source>
      <translation>Pavidalas</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="37"/>
      <source>X+</source>
      <translation>X+</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="56"/>
      <source>Y+</source>
      <translation>Y+</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="75"/>
      <source>Z+</source>
      <translation>Z+</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="94"/>
      <source>A+</source>
      <translation>A+</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="113"/>
      <source>B+</source>
      <translation>B+</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="132"/>
      <source>C+</source>
      <translation>C+</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="151"/>
      <source>X-</source>
      <translation>X-</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="170"/>
      <source>Y-</source>
      <translation>Y-</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="189"/>
      <source>Z-</source>
      <translation>Z-</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="208"/>
      <source>A-</source>
      <translation>A-</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="227"/>
      <source>B-</source>
      <translation>B-</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="246"/>
      <source>C-</source>
      <translation>C-</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="258"/>
      <source>Tool 0</source>
      <translation>Įrankis 0</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="263"/>
      <source>Tool</source>
      <translation>Įrankis</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="268"/>
      <source>Base 0</source>
      <translation>Pagrindas 0</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="273"/>
      <source>Base</source>
      <translation>Pagrindas</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="278"/>
      <source>World</source>
      <translation>Pasaulis</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="287"/>
      <source>50mm / 5°</source>
      <translation>50mm / 5°</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="292"/>
      <source>20mm / 2°</source>
      <translation>20mm / 2°</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="297"/>
      <source>10mm / 1°</source>
      <translation>10mm / 1°</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="302"/>
      <source>5mm / 0.5°</source>
      <translation>5mm / 0.5°</translation>
    </message>
    <message>
      <location filename="../../TaskRobotControl.ui" line="307"/>
      <source>1mm / 0.1°</source>
      <translation>1mm / 0,1 °</translation>
    </message>
  </context>
  <context>
    <name>TaskRobotMessages</name>
    <message>
      <location filename="../../TaskRobotMessages.ui" line="14"/>
      <source>Form</source>
      <translation>Pavidalas</translation>
    </message>
    <message>
      <location filename="../../TaskRobotMessages.ui" line="20"/>
      <source>clear</source>
      <translation>iIšvalyti</translation>
    </message>
  </context>
  <context>
    <name>TaskTrajectoryDressUpParameter</name>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="14"/>
      <source>Form</source>
      <translation>Pavidalas</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="20"/>
      <source>Speed &amp; Acceleration:</source>
      <translation>Greitis ir pagreitis:</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="29"/>
      <source>Speed:</source>
      <translation>Greitis:</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="55"/>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="92"/>
      <source>Use</source>
      <translation>Naudoti</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="66"/>
      <source>Accel:</source>
      <translation>Pagr.:</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="102"/>
      <source>Don't change Cont</source>
      <translation>Nekeisti Glotn</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="107"/>
      <source>Continues</source>
      <translation>Tęsiasi</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="112"/>
      <source>Discontinues</source>
      <translation>Nustoja</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="127"/>
      <source>Position and Orientation:</source>
      <translation>Dėstymas:</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="159"/>
      <source>Don't change Position &amp; Orientation</source>
      <translation>Nekeisti dėstymo</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="164"/>
      <source>Use Orientation</source>
      <translation>Naudoti erdvinę padėtį</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="169"/>
      <source>Add Position</source>
      <translation>Pridėti padėtį</translation>
    </message>
    <message>
      <location filename="../../TaskTrajectoryDressUpParameter.ui" line="174"/>
      <source>Add Orientation</source>
      <translation>Pridėti erdvinę padėtį</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="47"/>
      <source>Robot</source>
      <translation>Robotas</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="48"/>
      <source>Insert Robots</source>
      <translation>Įdėti robotus</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="49"/>
      <source>&amp;Robot</source>
      <translation>&amp;Robotas</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="50"/>
      <source>Export trajectory</source>
      <translation>Eksportuoti judėjimo kelią</translation>
    </message>
  </context>
</TS>
